@@ -689,6 +689,14 @@ int ci_acl_typelist_init(struct ci_acl_type_list *list)
     return 1;
 }
 
+void ci_acl_typelist_destroy(struct ci_acl_type_list *list)
+{
+    free(list->acl_type_list);
+    list->acl_type_list = NULL;
+    list->acl_type_list_size = 0;
+    list->acl_type_list_num = 0;
+}
+
 int ci_acl_typelist_add(struct ci_acl_type_list *list, const ci_acl_type_t *type)
 {
     ci_acl_type_t *cur;
@@ -718,6 +726,7 @@ int ci_acl_typelist_add(struct ci_acl_type_list *list, const ci_acl_type_t *type
     cur->name[MAX_NAME_LEN] = '\0';
     cur->type = type->type;
     cur->get_test_data = type->get_test_data;
+    cur->free_test_data = type->free_test_data;
     list->acl_type_list_num++;
     return 1;
 }
@@ -868,6 +877,11 @@ void ci_acl_reset()
     acl_load_defaults();
 }
 
+void ci_acl_destroy()
+{
+    ci_acl_typelist_destroy(&types_list);
+}
+
 const ci_acl_spec_t *ci_acl_search(const char *name)
 {
     return (const ci_acl_spec_t *)ci_acl_spec_search(specs_list, name);
