@@ -706,7 +706,6 @@ int cfg_include_config_file(const char *directive, const char **argv, void *setd
     cfg_file = argv[0];
     if (cfg_file[0] != '/') {  /*Win32 code? */
         snprintf(path, CI_MAX_PATH, CONFDIR "/%s", cfg_file);
-        path[CI_MAX_PATH - 1] = '\0';
         cfg_file = path;
     }
 
@@ -957,7 +956,7 @@ static struct ci_options_entry options[] = {
         opt_pre "D", NULL, NULL, cfg_set_debug_stdout,
         "Print debug info to stdout"
     },
-    {opt_pre "h", NULL, &HELP_MODE, ci_cfg_enable, "Do not run as daemon"},
+    {opt_pre "h", NULL, &HELP_MODE, ci_cfg_enable, "Show this help"},
     {NULL, NULL, NULL, NULL}
 };
 
@@ -986,6 +985,11 @@ int config(int argc, char **argv)
     return 1;
 }
 
+void config_destroy()
+{
+    ci_cfg_lib_destroy();
+}
+
 void cfg_default_value_restore_all();
 int reconfig()
 {
