@@ -71,7 +71,13 @@ void register_command_extend(const char *name, int type, void *data,
                              void (*command_action) (const char *name, int type,
                                      void *data))
 {
-    if (type != CHILD_START_CMD && type != CHILD_STOP_CMD && type != ONDEMAND_CMD) {
+    if (type != CI_CMD_CHILD_START &&
+        type != CI_CMD_CHILD_STOP &&
+        type != CI_CMD_ONDEMAND &&
+        type != CI_CMD_POST_CONFIG &&
+        type != CI_CMD_MONITOR_START &&
+        type != CI_CMD_MONITOR_STOP &&
+        type != CI_CMD_MONITOR_ONDEMAND) {
         ci_debug_printf(1, "Can not register extend command %s ! wrong type\n", name );
         return;
     }
@@ -99,6 +105,18 @@ void commands_reset()
     }
 }
 
+void commands_destroy()
+{
+    if (COMMANDS_QUEUE) {
+        ci_list_destroy(COMMANDS_QUEUE);
+        COMMANDS_QUEUE = NULL;
+    }
+    if (COMMANDS_LIST) {
+        ci_list_destroy(COMMANDS_LIST);
+        COMMANDS_LIST = NULL;
+    }
+}
+
 /*
 Currently we are using the following functions which defined in cfg_param.c file
 These functions must moved to a utils.c file ...
@@ -174,7 +192,7 @@ static int exec_cmd_step(void *data, const void *cmd)
     return 0;
 }
 
-static int execute_child_commands (int cmd_type)
+int execute_commands_no_lock (int cmd_type)
 {
     ci_debug_printf(5, "Going to execute child commands\n");
     if (COMMANDS_LIST == NULL) {
@@ -187,12 +205,12 @@ static int execute_child_commands (int cmd_type)
 
 int commands_execute_start_child()
 {
-    return execute_child_commands(CHILD_START_CMD);
+    return execute_commands_no_lock(CHILD_START_CMD);
 }
 
 int commands_execute_stop_child()
 {
-    return execute_child_commands(CHILD_STOP_CMD);
+    return execute_commands_no_lock(CHILD_STOP_CMD);
 }
 
 void ci_command_register_ctl_cmd(const char *name, int type, void (*command_action)(const char *name,int type, const char **argv))
@@ -232,26 +250,32 @@ void ci_command_schedule(const char *name, void *data, time_t afterSecs)
     ci_command_schedule_on(name, data, tm);
 }
 
+struct sheduled_cmd_exec_data {
+    time_t tm;
+    int type;
+};
+
 static int cb_check_queue(void *data, const void *item)
 {
     struct schedule_data *sch = (struct schedule_data *)item;
-    time_t tm = *((time_t *)data);
-    if (sch->when < tm) {
+    struct sheduled_cmd_exec_data  *exec_data = (struct sheduled_cmd_exec_data *) data;
+    assert(exec_data);
+    if (sch->when <= exec_data->tm) {
         ci_command_t *cmd = find_command(sch->name);
-        if (cmd) {
+        if (cmd && cmd->type == exec_data->type) {
             ci_debug_printf(9, "Execute command:%s \n", cmd->name);
             cmd->command_action_extend (cmd->name, cmd->type, (sch->data ? sch->data : cmd->data));
+            ci_thread_mutex_lock(&COMMANDS_MTX);
+            ci_list_remove(COMMANDS_QUEUE, sch);
+            ci_thread_mutex_unlock(&COMMANDS_MTX);
         }
-        ci_thread_mutex_lock(&COMMANDS_MTX);
-        ci_list_remove(COMMANDS_QUEUE, sch);
-        ci_thread_mutex_unlock(&COMMANDS_MTX);
     }
     return 0;
 }
 
-void commands_exec_scheduled()
+void commands_exec_scheduled(int cmd_type)
 {
-    time_t tm;
+    struct sheduled_cmd_exec_data exec_data;
     ci_debug_printf(10, "Going to execute child commands\n");
     if (COMMANDS_LIST == NULL) {
         ci_debug_printf(10, "None command registered\n");
@@ -260,6 +284,33 @@ void commands_exec_scheduled()
     if (!COMMANDS_QUEUE)
         return;
 
-    time(&tm);
-    ci_list_iterate(COMMANDS_QUEUE, &tm, cb_check_queue);
+    time(&exec_data.tm);
+    exec_data.type = cmd_type;
+    ci_list_iterate(COMMANDS_QUEUE, &exec_data, cb_check_queue);
+}
+
+void ci_command_register_child_cleanup(const char *name, void *data, void (*child_cleanup_handler) (const char *name, process_pid_t pid, int reason, void *data))
+{
+    ci_command_t cmd;
+    strncpy(cmd.name, name, CMD_NM_SIZE);
+    cmd.name[CMD_NM_SIZE - 1] = '\0';
+    cmd.type = CI_CMD_CHILD_CLEANUP;
+    cmd.data = data;
+    cmd.command_child_cleanup = child_cleanup_handler;
+    ci_thread_mutex_lock(&COMMANDS_MTX);
+    ci_list_push(COMMANDS_LIST, &cmd);
+    ci_thread_mutex_unlock(&COMMANDS_MTX);
+    ci_debug_printf(5, "Child cleanup command/handler %s registered\n", name);
+}
+
+void commands_exec_child_cleanup(process_pid_t pid, int reason)
+{
+    ci_command_t *cmd = NULL;
+    ci_debug_printf(5, "Child cleanup handlers for child %d will be executed\n", pid);
+    ci_thread_mutex_lock(&COMMANDS_MTX);
+    for (cmd = ci_list_first(COMMANDS_LIST); cmd != NULL; cmd = ci_list_next(COMMANDS_LIST)) {
+        if (cmd->type == CI_CMD_CHILD_CLEANUP && cmd->command_child_cleanup)
+            cmd->command_child_cleanup(cmd->name, pid, reason, cmd->data);
+    }
+    ci_thread_mutex_unlock(&COMMANDS_MTX);
 }
