@@ -277,29 +277,29 @@ static int write_once_to_outbuf(void *obj, const char *buf, size_t len)
 int ci_decompress_to_membuf(int encoding_format, const char *inbuf, size_t inlen, ci_membuf_t *outbuf, ci_off_t max_size)
 {
     switch (encoding_format) {
-	case CI_ENCODE_NONE:
-            return CI_UNCOMP_OK;
-            break;
+    case CI_ENCODE_NONE:
+        return CI_UNCOMP_OK;
+        break;
 #ifdef HAVE_ZLIB
-        case CI_ENCODE_GZIP:
-        case CI_ENCODE_DEFLATE:
-            return ci_inflate_to_membuf(inbuf, inlen, outbuf, max_size);
-            break;
+    case CI_ENCODE_GZIP:
+    case CI_ENCODE_DEFLATE:
+        return ci_inflate_to_membuf(inbuf, inlen, outbuf, max_size);
+        break;
 #endif
 #ifdef HAVE_BZLIB
-        case CI_ENCODE_BZIP2:
-            return ci_bzunzip_to_membuf(inbuf, inlen, outbuf, max_size);
-            break;
+    case CI_ENCODE_BZIP2:
+        return ci_bzunzip_to_membuf(inbuf, inlen, outbuf, max_size);
+        break;
 #endif
 #ifdef HAVE_BROTLI
-        case CI_ENCODE_BROTLI:
-            return ci_brinflate_to_membuf(inbuf, inlen, outbuf, max_size);
-            break;
+    case CI_ENCODE_BROTLI:
+        return ci_brinflate_to_membuf(inbuf, inlen, outbuf, max_size);
+        break;
 #endif
-        case CI_ENCODE_UNKNOWN:
-        default:
-            return CI_UNCOMP_ERR_ERROR;
-            break;
+    case CI_ENCODE_UNKNOWN:
+    default:
+        return CI_UNCOMP_ERR_ERROR;
+        break;
     }
 }
 
@@ -308,85 +308,98 @@ int ci_decompress_to_membuf(int encoding_format, const char *inbuf, size_t inlen
 int ci_decompress_to_simple_file(int encoding_format, const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size)
 {
     switch (encoding_format) {
-	case CI_ENCODE_NONE:
-            return CI_UNCOMP_OK;
-            break;
+    case CI_ENCODE_NONE:
+        return CI_UNCOMP_OK;
+        break;
 #ifdef HAVE_ZLIB
-        case CI_ENCODE_GZIP:
-        case CI_ENCODE_DEFLATE:
-            return ci_inflate_to_simple_file(inbuf, inlen, outbuf, max_size);
-            break;
+    case CI_ENCODE_GZIP:
+    case CI_ENCODE_DEFLATE:
+        return ci_inflate_to_simple_file(inbuf, inlen, outbuf, max_size);
+        break;
 #endif
 #ifdef HAVE_BZLIB
-        case CI_ENCODE_BZIP2:
-            return ci_bzunzip_to_simple_file(inbuf, inlen, outbuf, max_size);
-            break;
+    case CI_ENCODE_BZIP2:
+        return ci_bzunzip_to_simple_file(inbuf, inlen, outbuf, max_size);
+        break;
 #endif
 #ifdef HAVE_BROTLI
-        case CI_ENCODE_BROTLI:
-            return ci_brinflate_to_simple_file(inbuf, inlen, outbuf, max_size);
-            break;
+    case CI_ENCODE_BROTLI:
+        return ci_brinflate_to_simple_file(inbuf, inlen, outbuf, max_size);
+        break;
 #endif
-        case CI_ENCODE_UNKNOWN:
-        default:
-            return CI_UNCOMP_ERR_ERROR;
-            break;
+    case CI_ENCODE_UNKNOWN:
+    default:
+        return CI_UNCOMP_ERR_ERROR;
+        break;
     }
 }
 
 #ifdef HAVE_BROTLI
-#define DEFAULT_LGWIN	 22
-#define DEFAULT_QUALITY	 11
+#define DEFAULT_LGWIN    22
+#define DEFAULT_QUALITY  11
 #define kFileBufferSize 16384
 
-BROTLI_BOOL Br_Decompress(BrotliDecoderState* s, const char *buf, int inlen, void *outbuf, char *(*get_outbuf)(void *obj, unsigned int *len), int (*writefunc)(void *obj, const char *buf, size_t len), ci_off_t max_size)
+int Br_Decompress(BrotliDecoderState* s, const char *buf, int inlen, void *outbuf, char *(*get_outbuf)(void *obj, unsigned int *len), int (*writefunc)(void *obj, const char *buf, size_t len), ci_off_t max_size)
 {
     size_t available_in = 0;
     const uint8_t* next_in = NULL;
     size_t available_out = kFileBufferSize;
     uint8_t* next_out;
-    unsigned have, written;
+    unsigned have, written, can_write;
     long long outsize;
     size_t total_out = 0;
     BrotliDecoderResult result = BROTLI_DECODER_RESULT_NEEDS_MORE_INPUT;
-    uint8_t out[kFileBufferSize];
+    uint8_t *out, OUT[kFileBufferSize];
 
     ci_debug_printf(4, "data-compression: brotli decompress called size: %d\n",
-            inlen);
+                    inlen);
 
     next_in = (uint8_t *)buf;
     available_in = inlen;
     outsize = 0;
     for (;;) {
-        available_out = kFileBufferSize;
+        if (get_outbuf) {
+            unsigned int outbuf_size;
+            out = (uint8_t *)get_outbuf(outbuf, &outbuf_size);
+            if (!out)
+                return CI_UNCOMP_ERR_OUTPUT;
+            available_out = outbuf_size;
+        } else {
+            out = OUT;
+            available_out = kFileBufferSize;
+        }
         next_out = out;
         result = BrotliDecoderDecompressStream(s,
-                               &available_in, &next_in,
-                               &available_out,
-                               &next_out, &total_out);
+                                               &available_in, &next_in,
+                                               &available_out,
+                                               &next_out, &total_out);
         have = kFileBufferSize - available_out;
-        if (!have || (written =
-                  writefunc(outbuf, (char *)out, have)) != have) {
-            return BROTLI_FALSE;
+        can_write = (max_size > 0 && (max_size - outsize) < have) ? (max_size - outsize) : have;
+        if ((written = writefunc(outbuf, (char *)out, can_write)) != can_write) {
+            ci_debug_printf(2, "data-compression: brotli decoded data not written to output (%u/%u)\n", written, have);
+            return CI_UNCOMP_ERR_OUTPUT;
         }
         outsize += written;
-        if (max_size > 0 && outsize > max_size) {
-            if ( (outsize/inlen) > 100) {
+        if (written < have) {
+            if ((outsize/inlen) > 100) {
                 ci_debug_printf(1, "data-compression: brotli Compression ratio UncompSize/CompSize = %"
-                        PRINTF_OFF_T "/%" PRINTF_OFF_T " = %" PRINTF_OFF_T
-                        "! Is it a zip bomb? aborting!\n",
-                        (CAST_OFF_T)outsize,
-                        (CAST_OFF_T)inlen,
-                        (CAST_OFF_T)(outsize/inlen));
-                return BROTLI_FALSE;
-            }
-            else {
+                                PRINTF_OFF_T "/%" PRINTF_OFF_T " = %" PRINTF_OFF_T
+                                "! Is it a zip bomb? aborting!\n",
+                                (CAST_OFF_T)outsize,
+                                (CAST_OFF_T)inlen,
+                                (CAST_OFF_T)(outsize/inlen));
+                return CI_UNCOMP_ERR_BOMB;
+            } else {
                 ci_debug_printf(4, "data-compression: brotli Object is bigger than max allowed file\n");
-                return BROTLI_FALSE;
+                return CI_UNCOMP_ERR_NONE;
             }
         }
         switch (result) {
         case BROTLI_DECODER_RESULT_NEEDS_MORE_INPUT:
+            if (available_in == 0) {
+                ci_debug_printf(2, "data-compression: brotli needs more data, but there are not available\n");
+                return CI_UNCOMP_ERR_CORRUPT;
+            }
             ci_debug_printf(4, "data-compression: brotli needs more input\n");
             break;
         case BROTLI_DECODER_RESULT_NEEDS_MORE_OUTPUT:
@@ -394,15 +407,15 @@ BROTLI_BOOL Br_Decompress(BrotliDecoderState* s, const char *buf, int inlen, voi
             break;
         case BROTLI_DECODER_RESULT_SUCCESS:
             if (available_in != 0) {
-                ci_debug_printf(4, "data-compression: brotli available_in != 0\n");
-                return BROTLI_FALSE;
+                ci_debug_printf(4, "data-compression: brotli finished but available_in != 0\n");
+                return CI_UNCOMP_ERR_CORRUPT;
             }
             ci_debug_printf(4, "data-compression: brotli total uncompressed size: %lld (%lld)\n",
-                    outsize, (long long)total_out);
-            return BROTLI_TRUE;
+                            outsize, (long long)total_out);
+            return CI_UNCOMP_OK;
         default:
-            ci_debug_printf(4, "data-compression: brotli corrupt input\n");
-            return BROTLI_FALSE;
+            ci_debug_printf(2, "data-compression: brotli corrupt input\n");
+            return CI_UNCOMP_ERR_CORRUPT;
         }
 
     }
@@ -410,19 +423,17 @@ BROTLI_BOOL Br_Decompress(BrotliDecoderState* s, const char *buf, int inlen, voi
 
 int ci_mem_brinflate(const char *inbuf, int inlen, void *outbuf, char *(*get_outbuf)(void *obj, unsigned int *len), int (*writefunc)(void *obj, const char *buf, size_t len), ci_off_t max_size)
 {
-	BROTLI_BOOL ccode = BROTLI_TRUE;
-	BrotliDecoderState *s;
+    BROTLI_BOOL ccode = BROTLI_TRUE;
+    BrotliDecoderState *s;
 
-	s = BrotliDecoderCreateInstance(NULL, NULL, NULL);
-	if (!s) {
-		ci_debug_printf(4, "data-compression:  brotli out of memory\n");
-		return -1;
-	}
-	ccode = Br_Decompress(s, inbuf, inlen, outbuf, get_outbuf, writefunc, max_size);
-	BrotliDecoderDestroyInstance(s);
-	if (!ccode)
-		return -1;
-	return 1;
+    s = BrotliDecoderCreateInstance(NULL, NULL, NULL);
+    if (!s) {
+        ci_debug_printf(4, "data-compression: brotli out of memory\n");
+        return -1;
+    }
+    ccode = Br_Decompress(s, inbuf, inlen, outbuf, get_outbuf, writefunc, max_size);
+    BrotliDecoderDestroyInstance(s);
+    return ccode;
 }
 
 int ci_brinflate_to_membuf(const char *inbuf, size_t inlen, ci_membuf_t *outbuf, ci_off_t max_size)
@@ -444,9 +455,10 @@ static int brotli_inflate_step(const char *buf, int len, char *unzipped_buf, int
     struct unzipBuf ub;
     ub.buf = unzipped_buf;
     ub.buf_size = *unzipped_buf_len;
+    ub.out_len = 0;
     int ret = ci_mem_brinflate(buf, len,  &ub, get_buf_outbuf, write_once_to_outbuf, len);
     ci_debug_printf(5, "brotli_inflate_step: retcode %d, unzipped data: %d\n", ret, (int)ub.out_len);
-    if (ub.out_len > 0) {
+    if (ub.out_len > 0) { /* there are output data even if there are errors*/
         *unzipped_buf_len = ub.out_len;
         return CI_OK;
     }
@@ -569,8 +581,8 @@ do_mem_inflate_retry:
     inflateEnd(&strm);
     /*
       ret == Z_STREAM_END means that the decompression was succesfull
-      else the output data are corrupted or not produced at all. 
-      Example case is when the input data are not enough to produce 
+      else the output data are corrupted or not produced at all.
+      Example case is when the input data are not enough to produce
       a single byte of decompressed data, so the inflate() return Z_OK
       (eg during preview request with few preview data)
      */
@@ -596,6 +608,7 @@ static int zlib_inflate_step(const char *buf, int len, char *unzipped_buf, int *
     struct unzipBuf ub;
     ub.buf = unzipped_buf;
     ub.buf_size = *unzipped_buf_len;
+    ub.out_len = 0;
     int ret = ci_mem_inflate(buf, len,  &ub, get_buf_outbuf, write_once_to_outbuf, len);
     ci_debug_printf(5, "zlib_inflate_step: retcode %d, unzipped data: %d\n", ret, (int)ub.out_len);
     if (ub.out_len > 0) {
@@ -726,6 +739,7 @@ static int bzlib_uncompress_step(const char *buf, int len, char *unzipped_buf, i
     struct unzipBuf ub;
     ub.buf = unzipped_buf;
     ub.buf_size = *unzipped_buf_len;
+    ub.out_len = 0;
     int ret = ci_mem_bzunzip(buf, len,  &ub, get_buf_outbuf, write_once_to_outbuf, len);
     ci_debug_printf(5, "bzlib_uncompress_step: retcode %d, unzipped data: %d\n", ret, (int)ub.out_len);
     if (ub.out_len > 0) {
@@ -758,12 +772,12 @@ int ci_uncompress_preview(int compress_method, const char *buf, int len, char *u
     else
 #endif
 #ifdef HAVE_BROTLI
-    if (compress_method == CI_ENCODE_BROTLI)
-        return  brotli_inflate_step(buf, len, unzipped_buf, unzipped_buf_len);
-    else
+        if (compress_method == CI_ENCODE_BROTLI)
+            return  brotli_inflate_step(buf, len, unzipped_buf, unzipped_buf_len);
+        else
 #endif
 #ifdef HAVE_ZLIB
-        return zlib_inflate_step(buf, len, unzipped_buf, unzipped_buf_len);
+            return zlib_inflate_step(buf, len, unzipped_buf, unzipped_buf_len);
 #endif
     return CI_ERROR;
 }
