@@ -34,7 +34,7 @@ extern "C"
  * Arrays, stacks, queues and vectors related API.
  */
 
-typedef struct ci_array_item{
+typedef struct ci_array_item {
     char *name;
     void *value;
 } ci_array_item_t;
@@ -48,7 +48,7 @@ typedef struct ci_array_item{
 /**
    \typedef ci_array_t
    \ingroup SIMPLE_ARRAYS
-   * The ci_array_t objects can store a list of name/value pairs. Currently 
+   * The ci_array_t objects can store a list of name/value pairs. Currently
    * can grow up to a fixed size.
  */
 typedef struct ci_array {
@@ -81,7 +81,7 @@ typedef struct ci_array {
 #define ci_array_size(array) ((array)->count)
 
 /**
- * Allocate the required memory and initialize an ci_array_t object 
+ * Allocate the required memory and initialize an ci_array_t object
  \ingroup SIMPLE_ARRAYS
  \param max_mem_size the maximum memory to use
  \return the allocated object on success, or NULL on failure
@@ -99,7 +99,7 @@ CI_DECLARE_FUNC(ci_array_t *) ci_array_new(size_t max_mem_size);
 CI_DECLARE_FUNC(ci_array_t *) ci_array_new2(size_t items, size_t item_size);
 
 /**
- * Destroy an ci_array_t object 
+ * Destroy an ci_array_t object
  \ingroup SIMPLE_ARRAYS
  \param array a pointer to ci_array_t object to be destroyed
  *
@@ -150,7 +150,7 @@ CI_DECLARE_FUNC(void) ci_array_iterate(const ci_array_t *array, void *data, int
  \param pos The position of the item in array
  \return a pointer to the array item on success, NULL otherwise
  */
-CI_DECLARE_FUNC(const ci_array_item_t *)ci_array_get_item(ci_array_t *array, int pos);
+CI_DECLARE_FUNC(const ci_array_item_t *) ci_array_get_item(ci_array_t *array, int pos);
 
 /**
  \defgroup STR_ARRAYS   Arrays of strings related API
@@ -163,21 +163,22 @@ CI_DECLARE_FUNC(const ci_array_item_t *)ci_array_get_item(ci_array_t *array, int
  \ingroup STR_ARRAYS
  * An alias to the ci_array_t object. It is used to store items with string
  * values to an array.
- * The ci_str_array_new, ci_str_array_destroy, ci_str_array_add, ci_str_array_search
- * and ci_str_array_iterate defines are similar to the equivalent ci_array_* 
- * functions with the required typecasting to work with strings.
+ * The ci_str_array_new, ci_str_array_destroy, ci_str_array_add,
+ * ci_str_array_search and ci_str_array_iterate defines are similar to
+ * the equivalent ci_array_* functions with the required typecasting to
+ * work with strings.
  */
 typedef ci_array_t ci_str_array_t;
 #define ci_str_array_new ci_array_new
 #define ci_str_array_destroy ci_array_destroy
-#define ci_str_array_add(array, name, value) ci_array_add(array, name, value, (strlen(value)+1))
-#define ci_str_array_pop(array) ci_array_pop(array)
-#define ci_str_array_get_item(array, pos) ci_array_get_item(array, pos)
-#define ci_str_array_search(array, name) (const char *)ci_array_search(array, name)
+#define ci_str_array_add(array, name, value) ci_array_add((ci_array_t *)(array), name, value, (strlen(value)+1))
+#define ci_str_array_pop(array) ci_array_pop((ci_array_t *)(array))
+#define ci_str_array_get_item(array, pos) ci_array_get_item((ci_array_t *)(array), pos)
+#define ci_str_array_search(array, name) (const char *)ci_array_search((ci_array_t *)(array), name)
 #define ci_str_array_iterate ci_array_iterate
-#define ci_str_array_value(array, pos) ci_array_value(array, pos)
-#define ci_str_array_name(array, pos) ci_array_name(array, pos)
-#define ci_str_array_size(array) ci_array_size(array)
+#define ci_str_array_value(array, pos) ci_array_value((ci_array_t *)(array), pos)
+#define ci_str_array_name(array, pos) ci_array_name((ci_array_t *)(array), pos)
+#define ci_str_array_size(array) ci_array_size((ci_array_t *)(array))
 
 
 /**
@@ -189,7 +190,7 @@ typedef ci_array_t ci_str_array_t;
 /**
  \typedef ci_ptr_array_t
  \ingroup PTR_ARRAYS
- * The ci_ptr_array_t objects can store a list of name and pointer to object 
+ * The ci_ptr_array_t objects can store a list of name and pointer to object
  * pairs. It is similar to the ci_array_t object but does not store the value
  * but a pointer to the value.
  */
@@ -200,21 +201,21 @@ typedef ci_array_t ci_ptr_array_t;
  \ingroup PTR_ARRAYS
  * Return the value of item at position 'pos'
  */
-#define ci_ptr_array_value(array, pos) ci_array_value(array, pos)
+#define ci_ptr_array_value(array, pos) ci_array_value((ci_array_t *)(array), pos)
 
 /**
  \def ci_ptr_array_value(ptr_array, pos)
  \ingroup PTR_ARRAYS
  * Return the name of item at position 'pos'
  */
-#define ci_ptr_array_name(array, pos) ci_array_name(array, pos)
+#define ci_ptr_array_name(array, pos) ci_array_name((ci_array_t *)(array), pos)
 
 /**
  \def ci_ptr_array_value(ptr_array)
  \ingroup PTR_ARRAYS
  * Return the size of ptr_array
  */
-#define ci_ptr_array_size(array) ci_array_size(array)
+#define ci_ptr_array_size(array) ci_array_size((ci_array_t *)(array))
 
 /**
  \def ci_ptr_array_new()
@@ -236,7 +237,7 @@ CI_DECLARE_FUNC(ci_ptr_array_t *) ci_ptr_array_new2(size_t items);
  \ingroup PTR_ARRAYS
  * Destroy a ci_ptr_array_t object. Similar to the ci_array_destroy function
  */
-#define ci_ptr_array_destroy(ptr_array) ci_array_destroy(ptr_array)
+#define ci_ptr_array_destroy(ptr_array) ci_array_destroy((ci_array_t *)(ptr_array))
 
 /**
  * Search in an array for an item with the given name
@@ -254,14 +255,15 @@ CI_DECLARE_FUNC(void *) ci_ptr_array_search(ci_ptr_array_t *array, const char *n
  * Run the function fn for each item of the ci_ptr_array_t object. Similar to
  * the ci_array_iterate function
  */
-#define ci_ptr_array_iterate(ptr_array, data, fn) ci_array_iterate(ptr_array, data, fn)
+#define ci_ptr_array_iterate(ptr_array, data, fn) ci_array_iterate((ci_array_t *)(ptr_array), data, fn)
 
 /**
  * Add an name/value pair item to the ci_ptr_array_t object.
  \ingroup PTR_ARRAYS
  \param ptr_array a pointer to the ci_ptr_array_t object
- \ param name the name part of the name/value pair item to be added
- \ param value a pointer to the value part of the name/value pair item to be added
+ \param name the name part of the name/value pair item to be added
+ \param value a pointer to the value part of the name/value pair item to be
+ *      added
  \return a pointer to the new array item on success, NULL otherwise
  *
  */
@@ -279,7 +281,8 @@ CI_DECLARE_FUNC(const ci_array_item_t *) ci_ptr_array_pop(ci_ptr_array_t *ptr_ar
  * Pop and delete the last item of a  ci_ptr_array_t object.
  \ingroup PTR_ARRAYS
  \param ptr_array a pointer to the ci_ptr_array_t object
- \param name a pointer to a buffer where the name of the poped item will be store, or NULL
+ \param name a pointer to a buffer where the name of the poped item will be
+ *      store, or NULL
  \param name_size the size of name buffer
  \return a pointer to the value of the popped item
 */
@@ -290,7 +293,7 @@ CI_DECLARE_FUNC(void *) ci_ptr_array_pop_value(ci_ptr_array_t *ptr_array, char *
  \ingroup PTR_ARRAYS
  * Get an array item. Wrapper to the ci_array_get_item() function.
  */
-#define ci_ptr_array_get_item(array, pos) ci_array_get_item(array, pos)
+#define ci_ptr_array_get_item(array, pos) ci_array_get_item((ci_array_t *)(array), pos)
 
 /**
  \defgroup DYNAMIC_ARRAYS Dynamic arrays related API
@@ -342,7 +345,7 @@ typedef struct ci_dyn_array {
 #define ci_dyn_array_size(array) ((array)->count)
 
 /**
- * Allocate the required memory and initialize an ci_dyn_array_t object 
+ * Allocate the required memory and initialize an ci_dyn_array_t object
  \ingroup DYNAMIC_ARRAYS
  \param mem_size the initial size to use for dyn_array
  \return the allocated object on success, or NULL on failure
@@ -360,7 +363,7 @@ CI_DECLARE_FUNC(ci_dyn_array_t *) ci_dyn_array_new(size_t mem_size);
 CI_DECLARE_FUNC(ci_dyn_array_t *) ci_dyn_array_new2(size_t items, size_t item_size);
 
 /**
- * Destroy an ci_dyn_array_t object 
+ * Destroy an ci_dyn_array_t object
  \ingroup DYNAMIC_ARRAYS
  \param array a pointer to ci_dyn_array_t object to be destroyed
  */
@@ -391,7 +394,8 @@ CI_DECLARE_FUNC(const void *) ci_dyn_array_search(ci_dyn_array_t *array, const c
  \ingroup DYNAMIC_ARRAYS
  \param array a pointer to the ci_dyn_array_t object
  \param data a pointer to data which will be passed on fn function
- \param fn a pointer to the function which will be run for each array item.  The iteration will stop if the fn function return non zero value.
+ \param fn a pointer to the function which will be run for each array item.
+ *      The iteration will stop if the fn function return non zero value.
  */
 CI_DECLARE_FUNC(void) ci_dyn_array_iterate(const ci_dyn_array_t *array, void *data, int (*fn)(void *data, const char *name, const void *));
 
@@ -404,23 +408,23 @@ CI_DECLARE_FUNC(void) ci_dyn_array_iterate(const ci_dyn_array_t *array, void *da
 /**
  \typedef ci_ptr_dyn_array_t
  \ingroup PTR_DYNAMIC_ARRAYS
- * An alias to the ci_dyn_array_t object. It is used to store pointers 
+ * An alias to the ci_dyn_array_t object. It is used to store pointers
  * to an array.
  * The ci_ptr_dyn_array_new, ci_ptr_dyn_array_destroy, ci_ptr_dyn_array_search
- * and ci_ptr_dyn_array_iterate defines are  equivalent to the ci_dyn_array_* 
+ * and ci_ptr_dyn_array_iterate defines are  equivalent to the ci_dyn_array_*
  * functions with the required typecasting.
  */
 typedef ci_dyn_array_t ci_ptr_dyn_array_t;
 #define ci_ptr_dyn_array_new(size) ci_dyn_array_new(size)
 #define ci_ptr_dyn_array_new2(items, item_size) ci_dyn_array_new2(items, item_size)
-#define ci_ptr_dyn_array_destroy(ptr_array) ci_dyn_array_destroy(ptr_array)
-#define ci_ptr_dyn_array_search(ptr_array, name) ci_dyn_array_search(ptr_array, name)
-#define ci_ptr_dyn_array_iterate(ptr_array, data, fn) ci_dyn_array_iterate(ptr_array, data, fn)
+#define ci_ptr_dyn_array_destroy(ptr_array) ci_dyn_array_destroy((ci_dyn_array_t *)(ptr_array))
+#define ci_ptr_dyn_array_search(ptr_array, name) ci_dyn_array_search((ci_dyn_array_t *)(ptr_array), name)
+#define ci_ptr_dyn_array_iterate(ptr_array, data, fn) ci_dyn_array_iterate((ci_dyn_array_t *)(ptr_array), data, fn)
 
-#define ci_ptr_dyn_array_get_item(array, pos) ci_dyn_array_get_item(array, pos)
-#define ci_ptr_dyn_array_value(array, pos) ci_dyn_array_value(array, pos)
-#define ci_ptr_dyn_array_name(array, pos) ci_dyn_array_name(array, pos)
-#define ci_ptr_dyn_array_size(array) ci_dyn_array_size(array)
+#define ci_ptr_dyn_array_get_item(ptr_array, pos) ci_dyn_array_get_item((ci_dyn_array_t *)(ptr_array), pos)
+#define ci_ptr_dyn_array_value(ptr_array, pos) ci_dyn_array_value((ci_dyn_array_t *)(ptr_array), pos)
+#define ci_ptr_dyn_array_name(ptr_array, pos) ci_dyn_array_name((ci_dyn_array_t *)(ptr_array), pos)
+#define ci_ptr_dyn_array_size(ptr_array) ci_dyn_array_size((ci_dyn_array_t *)(ptr_array))
 
 /**
  * Add an name/value pair item to the array.
@@ -455,7 +459,7 @@ typedef struct ci_vector {
 } ci_vector_t;
 
 /**
- * Allocate the required memory and initialize a ci_vector_t object 
+ * Allocate the required memory and initialize a ci_vector_t object
  \ingroup VECTORS
  \param max_size the maximum memory to use
  \return the allocated object on success, or NULL on failure
@@ -463,7 +467,7 @@ typedef struct ci_vector {
 CI_DECLARE_FUNC(ci_vector_t *) ci_vector_create(size_t max_size);
 
 /**
- * Destroy an ci_vector_t object 
+ * Destroy an ci_vector_t object
  \ingroup VECTORS
  \param vector a pointer to ci_vector_t object to be destroyed
  */
@@ -484,7 +488,8 @@ CI_DECLARE_FUNC(void *) ci_vector_add(ci_vector_t *vector, const void *obj, size
  \ingroup VECTORS
  \param vector a pointer to the ci_vector_t object
  \param data a pointer to data which will be passed to the fn function
- \param fn a pointer to the function which will be run for each vector item. The iteration will stop if the fn function return non zero value.
+ \param fn a pointer to the function which will be run for each vector item.
+ *      The iteration will stop if the fn function return non zero value.
  */
 CI_DECLARE_FUNC(void) ci_vector_iterate(const ci_vector_t *vector, void *data, int (*fn)(void *data, const void *));
 
@@ -510,7 +515,7 @@ CI_DECLARE_FUNC(ci_vector_t *)ci_vector_cast_from_voidvoid(const void **p);
 /**
  \defgroup STR_VECTORS  Vectors of strings
  \ingroup VECTORS
- * 
+ *
  */
 
 /**
@@ -518,24 +523,25 @@ CI_DECLARE_FUNC(ci_vector_t *)ci_vector_cast_from_voidvoid(const void **p);
  \ingroup STR_VECTORS
  * The ci_str_vector is used to implement string vectors.
  * The  ci_str_vector_create, ci_str_vector_destroy,  ci_str_vector_add,
- * and ci_str_vector_pop defines are similar and equivalent to the ci_vector_* 
+ * and ci_str_vector_pop defines are similar and equivalent to the ci_vector_*
  * functions.
  */
 typedef ci_vector_t ci_str_vector_t;
 #define ci_str_vector_create ci_vector_create
 #define ci_str_vector_destroy ci_vector_destroy
-#define ci_str_vector_add(vect, string) ((const char *)ci_vector_add(vect, string, (strlen(string)+1)))
+#define ci_str_vector_add(vect, string) ((const char *)ci_vector_add((ci_vector_t *)(vect), string, (strlen(string)+1)))
 #define ci_str_vector_get(vector, i) (i < vector->count ? (const char *)vector->items[i]:  (const char *)NULL)
-#define ci_str_vector_pop(vect)  ((const char *)ci_vector_pop(vect))
-#define ci_str_vector_cast_to_charchar(vector) ((const char **)ci_vector_cast_to_voidvoid(vector))
-#define ci_str_vector_cast_from_charchar(p) (ci_vector_cast_from_voidvoid((void **)p))
+#define ci_str_vector_pop(vect)  ((const char *)ci_vector_pop((ci_vector_t *)(vect)))
+#define ci_str_vector_cast_to_charchar(vector) ((const char **)ci_vector_cast_to_voidvoid((ci_vector_t *)(vector)))
+#define ci_str_vector_cast_from_charchar(p) ((ci_str_vector_t *)ci_vector_cast_from_voidvoid((const void **)p))
 
 /**
  * Run the given function for each string vector item
  \ingroup STR_VECTORS
  \param vector a pointer to the ci_vector_t object
  \param data a pointer to data which will be passed to the fn function
- \param fn a pointer to the function which will be run for each string vector item. The iteration will stop if the fn function return non zero value.
+ \param fn a pointer to the function which will be run for each string vector
+ *      item. The iteration will stop if the fn function return non zero value.
  */
 CI_DECLARE_FUNC(void) ci_str_vector_iterate(const ci_str_vector_t *vector, void *data, int (*fn)(void *data, const char *));
 
@@ -582,7 +588,7 @@ CI_DECLARE_FUNC(void *) ci_ptr_vector_add(ci_vector_t *vector, void *pointer);
  *
  */
 
-typedef struct ci_list_item{
+typedef struct ci_list_item {
     void *item;
     struct ci_list_item *next;
 } ci_list_item_t;
@@ -592,8 +598,8 @@ typedef struct ci_list_item{
  \ingroup LISTS
  * The ci_list_t objects can store a list of objects, with a predefined size.
  * The list items can be removed.
- * The memory RAM space of list can not be decreased before the ci_list destroyed.
- * However the memory of removed items reused.
+ * The memory RAM space of list can not be decreased before the
+ * ci_list destroyed. However the memory of removed items reused.
  */
 typedef struct ci_list {
     ci_list_item_t *items;
@@ -610,10 +616,11 @@ typedef struct ci_list {
 } ci_list_t;
 
 /**
- * Allocate the required memory and initialize a ci_list_t object 
+ * Allocate the required memory and initialize a ci_list_t object
  \ingroup LISTS
  \param init_size the initial memory size to use
- \param obj_size the size of stored objects. If it is 0 then stores pointers to objects.
+ \param obj_size the size of stored objects. If it is 0 then stores pointers
+ *      to objects.
  \return the allocated object on success, or NULL on failure
  */
 CI_DECLARE_FUNC(ci_list_t *) ci_list_create(size_t init_size, size_t obj_size);
@@ -621,7 +628,8 @@ CI_DECLARE_FUNC(ci_list_t *) ci_list_create(size_t init_size, size_t obj_size);
 /**
  \def ci_list_first(ci_list_t *list)
  * Gets the first item of the list and updates the list cursor to the next item.
- * WARNING: do not mix this macro with ci_list_iterate. Use the ci_list_head/ci_list_tail macros instead
+ * WARNING: do not mix this macro with ci_list_iterate. Use the ci_list_head
+ * and ci_list_tail macros instead
  \ingroup LISTS
  \param list  a pointer to the ci_list_t object
  \return The first item if exist, NULL otherwise
@@ -631,7 +639,8 @@ CI_DECLARE_FUNC(ci_list_t *) ci_list_create(size_t init_size, size_t obj_size);
 
 /**
  \def ci_list_next()
- * Return the next item of the list and updates the list cursor to the next item.
+ * Return the next item of the list and updates the list cursor to the next
+ * item.
  * WARNING: It does not check for valid list object.
  * WARNING: do not mix this macro with ci_list_iterate!
  \ingroup LISTS
@@ -656,18 +665,19 @@ CI_DECLARE_FUNC(ci_list_t *) ci_list_create(size_t init_size, size_t obj_size);
 #define ci_list_tail(list) (list && list->last != NULL ? list->last->item : NULL)
 
 /**
- * Destroy an ci_list_t object 
+ * Destroy an ci_list_t object
  \ingroup LISTS
  \param list a pointer to ci_list_t object to be destroyed
  */
-    CI_DECLARE_FUNC(void) ci_list_destroy(ci_list_t *list);
+CI_DECLARE_FUNC(void) ci_list_destroy(ci_list_t *list);
 
 /**
  * Run the given function for each list item
  \ingroup LISTS
  \param list a pointer to the ci_list_t object
  \param data a pointer to data which will be passed to the fn function
- \param fn a pointer to the function which will be run for each vector item. The iteration will stop if the fn function return non zero value.
+ \param fn a pointer to the function which will be run for each vector item.
+ *      The iteration will stop if the fn function return non zero value.
  */
 CI_DECLARE_FUNC(void) ci_list_iterate(ci_list_t *list, void *data, int (*fn)(void *data, const void *obj));
 
@@ -726,7 +736,8 @@ CI_DECLARE_FUNC(int) ci_list_remove(ci_list_t *list, const void *obj);
 CI_DECLARE_FUNC(const void *) ci_list_search(ci_list_t *list, const void *data);
 
 /**
- * Return the first found item equal to the obj, using the cmp_func as comparison function.
+ * Return the first found item equal to the obj, using the cmp_func as
+ * comparison function.
  \ingroup LISTS
  \param list a pointer to the ci_list_t object
  \param obj pointer to an object to remove
@@ -751,7 +762,7 @@ CI_DECLARE_FUNC(void) ci_list_sort(ci_list_t *list);
 CI_DECLARE_FUNC(void) ci_list_sort2(ci_list_t *list, int (*cmp_func)(const void *obj1, const void *obj2, size_t obj_size));
 
 /*
-  The following three functions are undocumented. Probably will be removed or replaced 
+  The following three functions are undocumented. Probably will be removed or replaced
   by others.
  */
 CI_DECLARE_FUNC(void) ci_list_cmp_handler(ci_list_t *list, int (*cmp_func)(const void *obj, const void *user_data, size_t user_data_size));
