@@ -47,11 +47,11 @@ struct modules_list {
 static struct modules_list service_handlers;
 service_handler_module_t *default_service_handler;
 
-static struct modules_list loggers = {NULL, 0 , 0};
-static struct modules_list access_controllers = {NULL, 0 , 0};
-static struct modules_list auth_methods = {NULL, 0 , 0};
-static struct modules_list authenticators = {NULL, 0 , 0};
-static struct modules_list common_modules = {NULL, 0 , 0};
+static struct modules_list loggers = {NULL, 0, 0};
+static struct modules_list access_controllers = {NULL, 0, 0};
+static struct modules_list auth_methods = {NULL, 0, 0};
+static struct modules_list authenticators = {NULL, 0, 0};
+static struct modules_list common_modules = {NULL, 0, 0};
 
 
 static struct modules_list *modules_lists_table[] = {   /*Must follows the 'enum module_type'
@@ -410,7 +410,7 @@ service_handler_module_t *find_servicehandler_by_ext(const char *extension)
 
         if (found) {
             ci_debug_printf(3,
-                            "Found handler %s for service with extension:%s\n",
+                            "Found handler %s for service with extension: %s\n",
                             sh->name, extension);
             return sh;
         }
@@ -437,7 +437,7 @@ struct auth_hash authenticators_hash;
 int init_auth_hash(struct auth_hash *hash)
 {
     hash->usedsize = 0;
-    if (NULL == (hash->hash = malloc(STEP * sizeof(authenticator_module_t *)))) {
+    if (NULL == (hash->hash = malloc(STEP * sizeof(authenticator_module_t **)))) {
         hash->hash_size = STEP;
         return 0;
     }
