@@ -128,7 +128,7 @@ int ci_shared_cache_init(struct ci_cache *cache, const char *name)
     int i;
     struct shared_cache_data *data;
     data = (struct shared_cache_data *)malloc(sizeof(struct shared_cache_data));
-    data->entry_size = _CI_ALIGN(cache->max_object_size);
+    data->entry_size = _CI_ALIGN(cache->max_object_size > 0 ? cache->max_object_size : 1);
     data->entries = _CI_ALIGN(cache->mem_size) / data->entry_size;
 
     while (next_hash < data->entries) {
@@ -149,7 +149,7 @@ int ci_shared_cache_init(struct ci_cache *cache, const char *name)
     }
     data->stats = (struct shared_cache_stats *)data->mem_ptr;
     data->slots = data->mem_ptr + sizeof(struct shared_cache_stats);
-    memset(data->stats, 0 , sizeof(struct shared_cache_stats));
+    memset(data->stats, 0, sizeof(struct shared_cache_stats));
     data->stats->cache_users = 1;
 
     /*TODO: check for error*/
