@@ -207,10 +207,14 @@ int cfg_srv_allow206(const char *directive, const char **argv, void *setdata)
     }
     ci_debug_printf(1, "Setting parameter: %s=%s\n", directive, argv[0]);
 
-    if (strcasecmp(argv[0], "off")) {
+    if (strcasecmp(argv[0], "off") == 0) {
         ci_thread_rwlock_wrlock(&srv_xdata->lock);
         srv_xdata->disable_206 = 1;
+        srv_xdata->allow_206 = 0;
         ci_thread_rwlock_unlock(&srv_xdata->lock);
+    } else if (strcasecmp(argv[0], "on") != 0) {
+        ci_debug_printf(1, "Wrong argument '%s' for directive %s \n", argv[0], directive);
+        return 0;
     }
 
     return 1;
@@ -278,8 +282,8 @@ void init_extra_data(ci_service_xdata_t * srv_xdata, const char *service)
     char stat_group[1024];
     memset(srv_xdata, 0, sizeof(ci_service_xdata_t));
     ci_thread_rwlock_init(&srv_xdata->lock);
-    strcpy(srv_xdata->ISTag, "ISTag: ");
-    strcat(srv_xdata->ISTag, ISTAG "-XXXXXXXXX");
+    snprintf(srv_xdata->ISTag, sizeof(srv_xdata->ISTag), "ISTag: \"" ISTAG "-XXXXXXXXX\"");
+
     memset(srv_xdata->xincludes, 0, XINCLUDES_SIZE + 1);
     memset(srv_xdata->TransferPreview, 0, MAX_HEADER_SIZE + 1);
     memset(srv_xdata->TransferIgnore, 0, MAX_HEADER_SIZE + 1);
