@@ -57,6 +57,8 @@ int DoTransparent = 0;
 char *URLS[MAX_URLS];
 int URLS_COUNT = 0;
 
+char *BASE_URL = NULL;
+
 time_t START_TIME = 0;
 int FILES_NUMBER = 0;
 char **FILES = NULL;
@@ -81,7 +83,7 @@ ci_thread_mutex_t statsmtx;
 
 
 
-void print_stats()
+static void print_stats()
 {
     time_t rtime;
     time(&rtime);
@@ -130,7 +132,7 @@ static void sigint_handler(int sig)
     exit(0);
 }
 
-void str_trim(char *str)
+static void str_trim(char *str)
 {
     char *s, *e;
 
@@ -152,7 +154,7 @@ void str_trim(char *str)
     while (*(--e) == ' ' && e >= str) *e = '\0';
 }
 
-int load_urls(char *filename)
+static int load_urls(char *filename)
 {
     FILE *f;
 #define URL_SIZE  1024
@@ -179,7 +181,7 @@ int load_urls(char *filename)
     return 1;
 }
 
-char *xclient_header()
+static char *xclient_header()
 {
     if (!xclient_headers_num)
         return NULL;
@@ -188,14 +190,14 @@ char *xclient_header()
     return xclient_headers[indx];
 }
 
-void build_headers(int fd, ci_headers_list_t *headers)
+static void build_response_headers(int fd, ci_headers_list_t *headers)
 {
     struct stat filestat;
     int filesize;
     char lbuf[512];
     time_t ltimet;
 
-    ci_headers_add(headers, "200 OK HTTP/1.1");
+    ci_headers_add(headers, "HTTP/1.1 200 OK");
     ci_headers_add(headers, "Filetype: Unknown");
     ci_headers_add(headers, "User: chtsanti");
 
@@ -220,13 +222,12 @@ void build_headers(int fd, ci_headers_list_t *headers)
 
 }
 
-void build_request_headers(const char *url, const char *method, ci_headers_list_t *headers)
+static void build_request_headers(const char *url, const char *method, ci_headers_list_t *headers)
 {
-    char lbuf[1024];
+    char lbuf[8192];
     time_t ltimet;
 
-    snprintf(lbuf,1024, "%s %s HTTP/1.0", method, url);
-    lbuf[1023] = '\0';
+    snprintf(lbuf, sizeof(lbuf), "%s %s HTTP/1.1", method, url);
     ci_headers_add(headers, lbuf);
 
     strcpy(lbuf, "Date: ");
@@ -240,7 +241,7 @@ void build_request_headers(const char *url, const char *method, ci_headers_list_
 }
 
 
-int fileread(void *fd, char *buf, int len)
+static int fileread(void *fd, char *buf, int len)
 {
     int ret;
     ret = read(*(int *) fd, buf, len);
@@ -249,13 +250,13 @@ int fileread(void *fd, char *buf, int len)
     return ret;
 }
 
-int filewrite(void *fd, char *buf, int len)
+static int filewrite(void *fd, char *buf, int len)
 {
     return len;
 }
 
 
-int do_req(ci_request_t *req, char *url, int *keepalive, int transparent)
+static int do_req(ci_request_t *req, char *url, int *keepalive, int transparent)
 {
     int ret;
     char lbuf[1024];
@@ -279,20 +280,21 @@ int do_req(ci_request_t *req, char *url, int *keepalive, int transparent)
             host[511] = '\0';
             strcpy(path, "/index.html");
         }
-        snprintf(lbuf,1024, "GET %s HTTP/1.0", path);
-        lbuf[1023] = '\0';
+        snprintf(lbuf, sizeof(lbuf), "GET %s HTTP/1.1", path);
     } else {
         if (strstr(url, "://"))
-            snprintf(lbuf,1024, "GET %s HTTP/1.0", url);
+            snprintf(lbuf, sizeof(lbuf), "GET %s HTTP/1.1", url);
         else
-            snprintf(lbuf,1024, "GET http://%s HTTP/1.0", url);
-        lbuf[1023] = '\0';
+            snprintf(lbuf, sizeof(lbuf), "GET http://%s HTTP/1.1", url);
+        host[0] = '\0';
     }
 
     ci_headers_add(headers, lbuf);
-    snprintf(lbuf,1024, "Host: %s", host);
-    lbuf[1023] = '\0';
-    ci_headers_add(headers, lbuf);
+
+    if (host[0] != '\0') {
+        snprintf(lbuf,1024, "Host: %s", host);
+        ci_headers_add(headers, lbuf);
+    }
 
     strcpy(lbuf, "Date: ");
     time(&ltimet);
@@ -339,7 +341,7 @@ int do_req(ci_request_t *req, char *url, int *keepalive, int transparent)
     return 1;
 }
 
-int threadjobreqmod()
+static int threadjobreqmod()
 {
     ci_request_t *req;
     ci_connection_t *conn;
@@ -412,21 +414,28 @@ int threadjobreqmod()
     return 1;
 }
 
-int do_file(ci_request_t *req, char *input_file, int *keepalive)
+static int do_file(ci_request_t *req, char *input_file, int *keepalive)
 {
     int fd_in,fd_out;
     int ret, arand;
     int indx;
     ci_headers_list_t *headers, *request_headers = NULL;
     const char *useUrl = NULL;
+    char buf[4096];
 
-    if (URLS_COUNT > 0) {
+    if (BASE_URL) {
+        snprintf(buf, sizeof(buf), "%s%s%s", BASE_URL, input_file[0] != '/' ? "/" : "" ,input_file);
+        useUrl = buf;
+    } else if (URLS_COUNT > 0) {
         ci_thread_mutex_lock(&statsmtx);
         arand = rand();  /*rand is not thread safe .... */
         ci_thread_mutex_unlock(&statsmtx);
 
         indx = (int) ((((double) arand) / (double) RAND_MAX) * (double)URLS_COUNT);
         useUrl = URLS[indx];
+    } else {
+        snprintf(buf, sizeof(buf), "file://%s", input_file);
+        useUrl = buf;
     }
 
     if ((fd_in = open(input_file, O_RDONLY)) < 0) {
@@ -436,7 +445,7 @@ int do_file(ci_request_t *req, char *input_file, int *keepalive)
     fd_out = 0;
 
     headers = ci_headers_create();
-    build_headers(fd_in, headers);
+    build_response_headers(fd_in, headers);
     if (useUrl) {
         request_headers = ci_headers_create();
         build_request_headers(useUrl, "GET", request_headers);
@@ -477,7 +486,7 @@ int do_file(ci_request_t *req, char *input_file, int *keepalive)
 }
 
 
-int threadjobsendfiles()
+static int threadjobsendfiles()
 {
     ci_request_t *req;
     ci_connection_t *conn;
@@ -562,16 +571,7 @@ int threadjobsendfiles()
     return 1;
 }
 
-void usage(char *myname)
-{
-    printf("Usage:\n  %s servername service threadsnum max_requests file1 file2 .....\n",
-           myname);
-    printf("or:\n");
-    printf("  %s -req servername service threadsnum max_requests file\n",
-           myname);
-}
-
-int add_xheader(const char *directive, const char **argv, void *setdata)
+static int add_xheader(const char *directive, const char **argv, void *setdata)
 {
     ci_headers_list_t **xh = (ci_headers_list_t **)setdata;
     const char *h;
@@ -595,7 +595,7 @@ int add_xheader(const char *directive, const char **argv, void *setdata)
 }
 
 static int FILES_SIZE =0;
-int cfg_files_to_use(const char *directive, const char **argv, void *setdata)
+static int cfg_files_to_use(const char *directive, const char **argv, void *setdata)
 {
     assert ((void *)FILES == *(void **)setdata);
 
@@ -617,7 +617,7 @@ int cfg_files_to_use(const char *directive, const char **argv, void *setdata)
     return 1;
 }
 
-int add_xclient_headers(const char *directive, const char **argv, void *setdata)
+static int add_xclient_headers(const char *directive, const char **argv, void *setdata)
 {
     int ip1, ip2, ip3, ip4_start, ip4_end, i;
     const char *ip, *s;
@@ -661,7 +661,7 @@ int add_xclient_headers(const char *directive, const char **argv, void *setdata)
     return 1;
 }
 
-char *urls_file = NULL;
+static char *urls_file = NULL;
 
 
 static struct ci_options_entry options[] = {
@@ -677,6 +677,10 @@ static struct ci_options_entry options[] = {
         "-urls", "filename", &urls_file, ci_cfg_set_str,
         "File with urls to use for reqmod stress test"
     },
+    {
+        "-bU", "base_url", &BASE_URL, ci_cfg_set_str,
+        "Base URL  to use for respmod stress test urls computation"
+    },
     {
         "-req", NULL, &DoReqmod, ci_cfg_enable,
         "Send a request modification instead of response modification requests"
@@ -703,7 +707,8 @@ static struct ci_options_entry options[] = {
     {NULL, NULL, NULL, NULL}
 };
 
-void log_errors(ci_request_t * req, const char *format, ...)
+#if ! defined(_WIN32)
+static void log_errors(ci_request_t * req, const char *format, ...)
 {
     va_list ap;
     va_start(ap, format);
@@ -711,10 +716,12 @@ void log_errors(ci_request_t * req, const char *format, ...)
     va_end(ap);
 }
 
-void vlog_errors(ci_request_t * req, const char *format, va_list ap)
+#else
+static void vlog_errors(ci_request_t * req, const char *format, va_list ap)
 {
     vfprintf(stderr, format, ap);
 }
+#endif
 
 int main(int argc, char **argv)
 {
